<?php
/**
 * The class to register, update and display blocks
 *
 * It provides an easy API for people to add their own blocks
 * to the Aqua Page Builder
 *
 * @package Aqua Page Builder
 */

$aq_registered_blocks = array();

if(!class_exists('AQ_Block')) {
	class AQ_Block {
	 	
	 	//some vars
	 	var $id_base;
	 	var $block_options;
	 	var $instance;
	 	
	 	/* PHP4 constructor */
	 	function AQ_Block($id_base = false, $block_options = array()) {
	 		AQ_Block::__construct($id_base, $block_options);
	 	}
	 	
	 	/* PHP5 constructor */
	 	function __construct($id_base = false, $block_options = array()) {
	 		$this->id_base = isset($id_base) ? strtolower($id_base) : strtolower(get_class($this));
	 		$this->name = isset($block_options['name']) ? $block_options['name'] : ucwords(preg_replace("/[^A-Za-z0-9 ]/", '', $this->id_base));
	 		$this->block_options = $this->parse_block($block_options);
	 	}
	 	
	 	/**
	 	 * Block - display the block on front end
	 	 *
	 	 * Sub-class MUST override this or it will output an error
	 	 * with the class name for reference
	 	 */
	 	function block($instance) {
	 		extract($instance);
	 		echo __('function AQ_Block::block should not be accessed directly. Output generated by the ', 'framework') . strtoupper($id_base). ' Class';
	 	}
	 	
	 	/**
	 	 * The callback function to be called on blocks saving
	 	 * 
	 	 * You should use this to do any filtering, sanitation etc. The default
	 	 * filtering is sufficient for most cases, but nowhere near perfect!
	 	 */
	 	function update($new_instance, $old_instance) {
	 		$new_instance = array_map('htmlspecialchars', array_map('stripslashes', $new_instance));
	 		return $new_instance;
	 	}
	 	
	 	/** 
	 	 * The block settings form 
	 	 *
	 	 * Use subclasses to override this function and generate
	 	 * its own block forms
	 	 */
	 	function form($instance) {
	 		echo '<p class="no-options-block">' . __('There are no options for this block.', 'framework') . '</p>';
	 		return 'noform';
	 	}
	 	
	 	/** 
	 	 * Form callback function 
	 	 *
	 	 * Sets up some default values and construct the basic
	 	 * structure of the form. Unless you know exactly what you're
	 	 * doing, DO NOT override this function
	 	 */
	 	function form_callback($instance = array()) {
	 		//insert block options into instance
	 		$instance = is_array($instance) ? wp_parse_args($instance, $this->block_options) : $this->block_options;
	 		
	 		//insert the dynamic block_id
	 		$this->block_id = 'aq_block_' . $instance['number'];
	 		$instance['block_id'] = $this->block_id;
	 		
	 		//display the block
	 		$this->before_form($instance);
	 		$this->form($instance);
	 		$this->after_form($instance);
	 	}
	 	
	 	/**
	 	 * Block callback function
	 	 *
	 	 * Sets up some default values. Unless you know exactly what you're
	 	 * doing, DO NOT override this function
	 	 */
	 	function block_callback($instance) {
	 		//insert block options into instance
	 		$instance = is_array($instance) ? wp_parse_args($instance, $this->block_options) : $this->block_options;
	 		
	 		//insert the dynamic block_id
	 		$this->block_id = 'aq_block_' . $instance['number'];
	 		$instance['block_id'] = $this->block_id;
	 		
	 		//display the block
	 		$this->before_block($instance);
	 		$this->block($instance);
	 		$this->after_block($instance);
	 	}
	 	
	 	/* assign default block options if not yet set */
	 	function parse_block($block_options) {
	 		$defaults = array(
	 			'id_base' => $this->id_base,	//the classname
	 			'order' => 0, 					//block order
	 			'name' => $this->name,			//block name
	 			'size' => 'span12',				//default size
	 			'title' => '',					//title field
	 			'parent' => 0,					//block parent (for blocks inside columns)
	 			'number' => '__i__',			//block consecutive numbering
	 			'first' => false,				//column first
	 			'resizable' => 0,				//whether block is resizable/not
	 			'is_column' => 0,
				'shortcode_name' => '',
	 		);
	 		
	 		$block_options = is_array($block_options) ? wp_parse_args($block_options, $defaults) : $defaults;
	 		
	 		return $block_options;
	 	}
	 	
	 	
	 	//form header
	 	function before_form($instance) {
	 		extract($instance);
	 		
	 		$title = $title ? '<span class="in-block-title"> : '.$title.'</span>' : '';
	 		$resizable = $resizable ? '' : 'not-resizable';
			
			$name_class = ( substr($id_base, 0, 15) == 'aq_column_block' ) ? 'aq_column_block' : $id_base;
			
			$uniqueID = ( $id_base == 'aq_section_block' && $number <> '__i__' ) ? '<strong>Unique ID #section-'.$unique_id.'</strong>' : '<strong>Please "Save Template" before add CSS</strong>';
	 		
	 		echo '<li id="template-block-'.$number.'" class="block block-'.$name_class.' '. $size .' '.$resizable.'">',
	 				'<dl class="block-bar">',
	 					'<dt class="block-handle">',
	 						'<div class="block-title">',
	 							//$name ,
								$name , ( $shortcode_name == 'heading' && !empty($st_title) ) ? ' : <em style="font-weight:normal;">'.$st_title.'</em>' : '' ,
	 						'</div>',
	 						'<span class="block-controls">',
	 							'<a class="block-edit" id="edit-'.$number.'" title="Edit Block" href="#block-settings-'.$number.'">Edit Block</a>',
								//'<a class="block-edit thickbox" id="edit-'.$number.'" title="Manage '.$name.'" href="#TB_inline?width=640&inlineId=block-settings-'.$number.'">Edit Block</a>',
								'<a class="block-delete" title="Delete '.$name.'" href="#">Delete</a>',
	 						'</span>',
	 					'</dt>',
	 				'</dl>',
	 				'<div class="block-settings cf" id="block-settings-'.$number.'">',
					'<div>'.$uniqueID.'</div>';
	 	}
	 	
	 	//form footer
	 	function after_form($instance) {
	 		extract($instance);
	 		
	 		$block_saving_id = 'aq_blocks[aq_block_'.$number.']';
	 			
	 			echo '<div class="block-control-actions cf"><input type="button" name="button" value="Close" class="close button button-primary"></div>';
	 			echo '<input type="hidden" class="id_base" name="'.$this->get_field_name('id_base').'" value="'.$id_base.'" />';
	 			echo '<input type="hidden" class="name" name="'.$this->get_field_name('name').'" value="'.$name.'" />';
	 			echo '<input type="hidden" class="order" name="'.$this->get_field_name('order').'" value="'.$order.'" />';
	 			echo '<input type="hidden" class="size" name="'.$this->get_field_name('size').'" value="'.$size.'" />';
	 			echo '<input type="hidden" class="parent" name="'.$this->get_field_name('parent').'" value="'.$parent.'" />';
	 			echo '<input type="hidden" class="number" name="'.$this->get_field_name('number').'" value="'.$number.'" />';
	 		echo '</div>',
	 			'</li>';
	 	}
	 	
	 	/* block header */
	 	function before_block($instance) {
	 		extract($instance);
	 		$column_class = $first ? 'aq-first' : '';
			
			/*
			if ( substr($id_base, 0, 15) <> 'aq_column_block' && $parent == 0 ) {
				echo '</div>';
				echo '<div class="row-fluid">';
			}			
			elseif ( substr($id_base, 0, 15) == 'aq_column_block' && $first == 1 ) {
				echo '</div>';
				echo '<div class="row-fluid">';
			}
	 		
	 		echo '<div id="aq-block-'.$template_id.'-'.$number.'" class="aq-block aq-block-'.$id_base.' aq_'.$size.' '.$column_class.' cf">';
			*/
			
			if ( substr($id_base, 0, 15) == 'aq_column_block' ) {
				echo '<div class="st-column '.$size.'">';
			}
	 	}
	 	
	 	/* block footer */
	 	function after_block($instance) {
	 		extract($instance);
	 		if ( substr($id_base, 0, 15) == 'aq_column_block' ) {
				echo '</div>';	
			}
	 	}
	 	
	 	function get_field_id($field) {
	 		$field_id = isset($this->block_id) ? $this->block_id . '_' . $field : '';
	 		return $field_id;
	 	}
	 	
	 	function get_field_name($field) {
	 		$field_name = isset($this->block_id) ? 'aq_blocks[' . $this->block_id. '][' . $field . ']': '';
	 		return $field_name;
	 	}
		
		function display_shortcode($instance)
		{
			extract($instance);
			//print_r($instance);
			
			// get config file
			include(ADMIN_PATH . 'shortcodes/tinymce/config.php');
			
			$shortcode_tag = $zilla_shortcodes[$shortcode_name]['shortcode'];
			
			preg_match_all('#{{.*}}#isU', $shortcode_tag, $matches);
			
			if ( is_array($matches) && count($matches) > 0 )
			{			
				$new_match = array();
				foreach ($matches[0] as $k => $match) 
				{
					if ( $match <> '{{child_shortcode}}' ) 
					{
						$attr = str_replace(array('{{','}}'), '', $match);
						$attr = ${'st_' . $attr};
						$new_match[] = html_entity_decode($attr);
					}
					else 
					{
						$child_shortcode_tag = $zilla_shortcodes[$shortcode_name]['child_shortcode']['shortcode'];
						preg_match_all('#{{.*}}#isU', $child_shortcode_tag, $child_matches);
						//print_r($st_child);
						
						$child_shortcode = '';
						$new_child_match = array();
						foreach ($st_child as $key => $val) 
						{
							if ( is_array($child_matches) && count($child_matches) > 0 )
							{								
								foreach ($child_matches[0] as $child_k => $child_match) 
								{
									$child_attr = str_replace(array('{{','}}'), '', $child_match);
									$new_child_match[$key][$child_attr] = '{{'.$child_attr.'}}';
								}
							}
							$child_shortcode .= str_replace($new_child_match[$key], array_map("html_entity_decode", $val), $child_shortcode_tag)."\n";
						}
						//print_r($new_child_match);
						$new_match[] = $child_shortcode;
					}
				}			
				
				$shortcode_tag = str_replace($matches[0], $new_match, $shortcode_tag);
			}
			
			echo do_shortcode($shortcode_tag);
		}
		
		function formate_shortcode($instance)
		{
			extract($instance);
			
			// get config file
			include(ADMIN_PATH . 'shortcodes/tinymce/config.php');
			
			$has_child = false;
			if( isset( $zilla_shortcodes[$shortcode_name]['child_shortcode'] ) ) $has_child = true;
			
			if( isset( $zilla_shortcodes ) && is_array( $zilla_shortcodes ) )
			{
				// get shortcode config stuff
				$params = $zilla_shortcodes[$shortcode_name]['params'];
				
				// filters and excutes params
				foreach( $params as $pkey => $param )
				{
					if ( !isset($param['desc']) ) $param['desc'] = '';
					if ( !isset($param['std']) ) $param['std'] = '';
					
					$param_value = isset(${'st_' . $pkey}) ? ${'st_' . $pkey} : $param['std'];
					
					switch( $param['type'] )
					{
						case 'text':
							?>
							<p class="description">
								<label for="<?php echo $this->get_field_id('st_'.$pkey) ?>">
									<strong><?php echo $param['label']; ?></strong><br />
									<?php echo aq_field_input('st_'.$pkey, $block_id, $param_value, $size = 'full') ?><br />
									<?php echo $param['desc']; ?>
								</label>
							</p>
							<?php
						break;							
						case 'textarea':
							?>
							<p class="description">
								<label for="<?php echo $this->get_field_id('st_'.$pkey) ?>">
									<strong><?php echo $param['label']; ?></strong><br />
									<?php echo aq_field_textarea('st_'.$pkey, $block_id, $param_value, $size = 'full') ?><br />
									<?php echo $param['desc']; ?>
								</label>
							</p>
							<?php					
						break;							
						case 'select':						
							?>
							<p class="description">
								<label for="<?php echo $this->get_field_id('st_'.$pkey) ?>">
									<strong><?php echo $param['label']; ?></strong><br />
									<?php echo aq_field_select('st_'.$pkey, $block_id, $param['options'], $param_value) ?><br />
									<?php echo $param['desc']; ?>
								</label>
							</p>
							<?php							
						break;
					}
				}
			}
			
			if ( $has_child )
			{
				?>
				<div class="description cf">
					<ul id="aq-sortable-list-<?php echo $block_id ?>" class="aq-sortable-list" rel="<?php echo $block_id ?>">
						<?php
						$tabs = is_array($st_child) ? $st_child : $defaults['st_child'];
						$count = 1;
						foreach($tabs as $tab) {	
							$this->formate_shortcode_child($tab, $count);
							$count++;
						}
						?>
					</ul>
					<p></p>
					<a href="#" rel="<?php echo $shortcode_name; ?>" class="aq-sortable-add-new button">Add New</a>
					<p></p>
				</div>
				<?php
			}
		}
		
		function formate_shortcode_child($tab = array(), $count = 0)
		{			
			$shortcode_name = $this->block_options['shortcode_name'];
			
			// get config file
			include(ADMIN_PATH . 'shortcodes/tinymce/config.php');
			
			if( isset( $zilla_shortcodes ) && is_array( $zilla_shortcodes ) )
			{
				// get shortcode config stuff
				$params = $zilla_shortcodes[$shortcode_name]['child_shortcode']['params'];
				
				$tab_title = 'Item '.$count;
				if ( isset($tab['title']) ) $tab_title = $tab['title'];
				
				?>
				<li id="<?php echo $this->get_field_id('tabs') ?>-sortable-item-<?php echo $count ?>" class="sortable-item" rel="<?php echo $count ?>">
					<div class="sortable-head cf">
						<div class="sortable-title">
							<strong><?php echo $tab_title; ?></strong>
						</div>
						<div class="sortable-handle">
							<a href="#">Open / Close</a>
						</div>
					</div>
					
					<div class="sortable-body">
					<?php
					// filters and excutes params
					foreach( $params as $pkey => $param )
					{
						if ( !isset($param['desc']) ) $param['desc'] = '';
						if ( !isset($param['std']) ) $param['std'] = '';
						
						$param_value = isset($tab[$pkey]) ? $tab[$pkey] : $param['std'];
						
						switch( $param['type'] )
						{
							case 'text':
								?>
								<p class="tab-desc description">									
									<label for="<?php echo $this->get_field_id('st_child') ?>-<?php echo $count ?>-<?php echo $pkey ?>">
										<strong><?php echo $param['label']; ?></strong><br />
										<input type="text" id="<?php echo $this->get_field_id('st_child') ?>-<?php echo $count ?>-<?php echo $pkey ?>" class="input-full" name="<?php echo $this->get_field_name('st_child') ?>[<?php echo $count ?>][<?php echo $pkey ?>]" value="<?php echo $param_value ?>" /><br />
										<?php echo $param['desc']; ?>
									</label>
								</p>
								<?php
							break;
							case 'textarea':
								?>
								<p class="tab-desc description">
									<label for="<?php echo $this->get_field_id('st_child') ?>-<?php echo $count ?>-<?php echo $pkey ?>">
										<strong><?php echo $param['label']; ?></strong><br />
										<textarea id="<?php echo $this->get_field_id('st_child') ?>-<?php echo $count ?>-<?php echo $pkey ?>" class="textarea-full" name="<?php echo $this->get_field_name('st_child') ?>[<?php echo $count ?>][<?php echo $pkey ?>]" rows="5"><?php echo $param_value ?></textarea><br />
										<?php echo $param['desc']; ?>
									</label>
								</p>
								<?php					
							break;
							case 'select':
								?>
								<p class="tab-desc description">
									<label for="<?php echo $this->get_field_id('st_child') ?>-<?php echo $count ?>-<?php echo $pkey ?>">
										<strong><?php echo $param['label']; ?></strong><br />
										<select id="<?php echo $this->get_field_id('st_child') ?>-<?php echo $count ?>-<?php echo $pkey ?>" name="<?php echo $this->get_field_name('st_child') ?>[<?php echo $count ?>][<?php echo $pkey ?>]">
											<?php
											foreach ( $param['options'] as $key => $value ) {
												echo '<option value="'.$key.'" '.selected( $param_value, $key, false ).'>'.htmlspecialchars($value).'</option>';
											}
											?>
										</select><br />
										<?php echo $param['desc']; ?>
									</label>
								</p>
								<?php
							break;
						}
					}
					?>
					<p class="tab-desc description" style="text-align:right;"><a href="#" class="sortable-delete">Delete</a></p>
					</div>
				</li>
				<?php
			}
		}
	 	
	}
}