<?php

if ( !isset($content_width) ) {
	$content_width = 960;
}
if ( function_exists('add_theme_support') ) {
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'nav_menus' );
	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' );
	add_theme_support( 'post-formats', array( 'gallery', 'quote', 'video', 'audio' ) );
	add_theme_support( 'woocommerce' );
}
add_editor_style();


/*******************************************************************
Register Menu
********************************************************************/
if ( function_exists('register_nav_menus') )
{
	register_nav_menus(
		array(
			'primary' => __(THEMENAME . ' Primary Menu', 'slicetheme'),
			'secondary' => __(THEMENAME . ' Secondary Menu', 'slicetheme')
		)
	);
}


/*******************************************************************
Register Sidebar
********************************************************************/
if ( function_exists('register_sidebar') )
{
	$sidebar1 = array(
				  'General',
				  'Shop',
				  'Footer Column 1', 
				  'Footer Column 2', 
				  'Footer Column 3', 
				  'Footer Column 4'
				  );
	
	$sidebar2 = st_option('sidebar');
	
	$sidebars = array_merge( (array)$sidebar1, (array)$sidebar2);
	$sidebars = array_filter($sidebars);
	
	foreach ($sidebars as $sidebar)
	{
		register_sidebar(array(
		'name' => $sidebar,
		'before_widget' => '<section id="%1$s" class="widget %2$s">', 
		'after_widget' => '</section>', 
		'before_title' => '<h3 class="widget-title"><span>', 
		'after_title' => '</span></h3>', 
		));
	}
}


/*******************************************************************
Register Post Type
********************************************************************/
add_action('init', 'portfolio_post_type');
add_action('init', 'team_post_type');
add_action('init', 'job_post_type');
add_action('init', 'testimonial_post_type');
add_action('init', 'client_post_type');
add_action('init', 'pricing_post_type');
add_action('init', 'faq_post_type');

function portfolio_post_type() 
{
	$labels = array(
		'name' => _x('Portfolio', 'post type general name', 'slicetheme'),
		'singular_name' => _x('Portfolio', 'post type singular name', 'slicetheme'),
		'add_new' => _x('Add New', 'portfolio', 'slicetheme'),
		'add_new_item' => __('Add New Portfolio', 'slicetheme'),
		'edit_item' => __('Edit Portfolio', 'slicetheme'),
		'new_item' => __('New Portfolio', 'slicetheme'),
		'all_items' => __('All Portfolio', 'slicetheme'),
		'view_item' => __('View Portfolio', 'slicetheme'),
		'search_items' => __('Search Portfolio', 'slicetheme'),
		'not_found' =>  __('No Portfolio Found', 'slicetheme'),
		'not_found_in_trash' => __('No Portfolio Found in Trash', 'slicetheme'), 
		'parent_item_colon' => ''
	);
	
	$args = array(
		'labels' => $labels,
		'public' => true,
		'show_ui' => true,
		'capability_type' => 'post',
		'hierarchical' => false,
		'rewrite' => array('slug' => 'portfolio-item', 'with_front' => true),
		'query_var' => true,
		'show_in_nav_menus'=> false,
		'supports' => array('title', 'editor')
	);
	
	register_post_type( 'portfolio' , $args );	
	
	register_taxonomy('portfolio-category', 
		array('portfolio'), 
		array(
		'hierarchical' => true, 
		'label' => 'Portfolio Categories', 
		'singular_label' => 'Portfolio Categories', 
		'rewrite' => true,
		'query_var' => true,		
		'show_in_nav_menus'=> false
	));
}

function team_post_type() 
{
	$labels = array(
		'name' => _x('Teams', 'post type general name', 'slicetheme'),
		'singular_name' => _x('Team', 'post type singular name', 'slicetheme'),
		'add_new' => _x('Add New', 'Team', 'slicetheme'),
		'add_new_item' => __('Add New Team', 'slicetheme'),
		'edit_item' => __('Edit Team', 'slicetheme'),
		'new_item' => __('New Team', 'slicetheme'),
		'all_items' => __('All Teams', 'slicetheme'),
		'view_item' => __('View Team', 'slicetheme'),
		'search_items' => __('Search Team', 'slicetheme'),
		'not_found' =>  __('No Team Found', 'slicetheme'),
		'not_found_in_trash' => __('No Team Found in Trash', 'slicetheme'), 
		'parent_item_colon' => ''
	);
	
	$args = array(
		'labels' => $labels,
		'public' => true,
		'show_ui' => true,
		'capability_type' => 'post',
		'hierarchical' => false,
		'rewrite' => array('slug' => 'team-item', 'with_front' => true),
		'query_var' => true,
		'show_in_nav_menus'=> false,
		'exclude_from_search' => true,
		'supports' => array('title', 'excerpt', 'page-attributes')
	);
	
	register_post_type( 'team' , $args );
	
	register_taxonomy('team-category', 
		array('team'), 
		array(
		'hierarchical' => true, 
		'label' => 'Team Categories', 
		'singular_label' => 'Team Categories', 
		'rewrite' => true,
		'query_var' => true,
		'show_in_nav_menus'=> false
	));
}

function job_post_type() 
{
	$labels = array(
		'name' => _x('Jobs', 'post type general name', 'slicetheme'),
		'singular_name' => _x('Job', 'post type singular name', 'slicetheme'),
		'add_new' => _x('Add New', 'Job', 'slicetheme'),
		'add_new_item' => __('Add New Job', 'slicetheme'),
		'edit_item' => __('Edit Job', 'slicetheme'),
		'new_item' => __('New Job', 'slicetheme'),
		'all_items' => __('All Jobs', 'slicetheme'),
		'view_item' => __('View Job', 'slicetheme'),
		'search_items' => __('Search Job', 'slicetheme'),
		'not_found' =>  __('No Job Found', 'slicetheme'),
		'not_found_in_trash' => __('No Job Found in Trash', 'slicetheme'), 
		'parent_item_colon' => ''
	);
	
	$args = array(
		'labels' => $labels,
		'public' => true,
		'show_ui' => true,
		'capability_type' => 'post',
		'hierarchical' => false,
		'rewrite' => array('slug' => 'job-item', 'with_front' => true),
		'query_var' => true,
		'show_in_nav_menus'=> false,
		'exclude_from_search' => true,
		'supports' => array('title', 'editor', 'page-attributes')
	);
	
	register_post_type( 'job' , $args );
}

function testimonial_post_type() 
{
	$labels = array(
		'name' => _x('Testimonials', 'post type general name', 'slicetheme'),
		'singular_name' => _x('Testimonial', 'post type singular name', 'slicetheme'),
		'add_new' => _x('Add New', 'Testimonial', 'slicetheme'),
		'add_new_item' => __('Add New Testimonial', 'slicetheme'),
		'edit_item' => __('Edit Testimonial', 'slicetheme'),
		'new_item' => __('New Testimonial', 'slicetheme'),
		'all_items' => __('All Testimonials', 'slicetheme'),
		'view_item' => __('View Testimonial', 'slicetheme'),
		'search_items' => __('Search Testimonial', 'slicetheme'),
		'not_found' =>  __('No Testimonial Found', 'slicetheme'),
		'not_found_in_trash' => __('No Testimonial Found in Trash', 'slicetheme'), 
		'parent_item_colon' => ''
	);
	
	$args = array(
		'labels' => $labels,
		'public' => true,
		'show_ui' => true,
		'capability_type' => 'post',
		'hierarchical' => false,
		'rewrite' => array('slug' => 'testimonial-item', 'with_front' => true),
		'query_var' => true,
		'show_in_nav_menus'=> false,
		'exclude_from_search' => true,
		'supports' => array('title', 'excerpt')
	);
	
	register_post_type( 'testimonial' , $args );
}

function client_post_type() 
{
	$labels = array(
		'name' => _x('Clients', 'post type general name', 'slicetheme'),
		'singular_name' => _x('Client', 'post type singular name', 'slicetheme'),
		'add_new' => _x('Add New', 'Client', 'slicetheme'),
		'add_new_item' => __('Add New Client', 'slicetheme'),
		'edit_item' => __('Edit Client', 'slicetheme'),
		'new_item' => __('New Client', 'slicetheme'),
		'all_items' => __('All Clients', 'slicetheme'),
		'view_item' => __('View Client', 'slicetheme'),
		'search_items' => __('Search Client', 'slicetheme'),
		'not_found' =>  __('No Client Found', 'slicetheme'),
		'not_found_in_trash' => __('No Client Found in Trash', 'slicetheme'), 
		'parent_item_colon' => ''
	);
	
	$args = array(
		'labels' => $labels,
		'public' => true,
		'show_ui' => true,
		'capability_type' => 'post',
		'hierarchical' => false,
		'rewrite' => array('slug' => 'client-item', 'with_front' => true),
		'query_var' => true,
		'show_in_nav_menus'=> false,
		'exclude_from_search' => true,
		'supports' => array('title')
	);
	
	register_post_type( 'client' , $args );
}

function pricing_post_type() 
{
	$labels = array(
		'name' => _x('Pricing Tables', 'post type general name', 'slicetheme'),
		'singular_name' => _x('Price', 'post type singular name', 'slicetheme'),
		'add_new' => _x('Add New', 'Price', 'slicetheme'),
		'add_new_item' => __('Add New Price', 'slicetheme'),
		'edit_item' => __('Edit Price', 'slicetheme'),
		'new_item' => __('New Price', 'slicetheme'),
		'all_items' => __('All Pricing Tables', 'slicetheme'),
		'view_item' => __('View Price', 'slicetheme'),
		'search_items' => __('Search Price', 'slicetheme'),
		'not_found' =>  __('No Price Found', 'slicetheme'),
		'not_found_in_trash' => __('No Price Found in Trash', 'slicetheme'), 
		'parent_item_colon' => ''
	);
	
	$args = array(
		'labels' => $labels,
		'public' => true,
		'show_ui' => true,
		'capability_type' => 'post',
		'hierarchical' => false,
		'rewrite' => array('slug' => 'pricing-item', 'with_front' => true),
		'query_var' => true,
		'show_in_nav_menus'=> false,
		'exclude_from_search' => true,
		'supports' => array('title', 'editor', 'page-attributes')
	);
	
	register_post_type( 'pricing' , $args );
	
	register_taxonomy('pricing-category', 
		array('pricing'), 
		array(
		'hierarchical' => true, 
		'label' => 'Pricing Categories', 
		'singular_label' => 'Pricing Categories', 
		'rewrite' => true,
		'query_var' => true,
		'show_in_nav_menus'=> false
	));
}

function faq_post_type() 
{
	$labels = array(
		'name' => _x('FAQs', 'post type general name', 'slicetheme'),
		'singular_name' => _x('FAQ', 'post type singular name', 'slicetheme'),
		'add_new' => _x('Add New', 'FAQ', 'slicetheme'),
		'add_new_item' => __('Add New FAQ', 'slicetheme'),
		'edit_item' => __('Edit FAQ', 'slicetheme'),
		'new_item' => __('New FAQ', 'slicetheme'),
		'all_items' => __('All FAQs', 'slicetheme'),
		'view_item' => __('View FAQ', 'slicetheme'),
		'search_items' => __('Search FAQ', 'slicetheme'),
		'not_found' =>  __('No FAQ Found', 'slicetheme'),
		'not_found_in_trash' => __('No FAQ Found in Trash', 'slicetheme'), 
		'parent_item_colon' => ''
	);
	
	$args = array(
		'labels' => $labels,
		'public' => true,
		'show_ui' => true,
		'capability_type' => 'post',
		'hierarchical' => false,
		'rewrite' => array('slug' => 'faq-item', 'with_front' => true),
		'query_var' => true,
		'show_in_nav_menus'=> false,
		'exclude_from_search' => true,
		'supports' => array('title', 'editor', 'page-attributes')
	);
	
	register_post_type( 'faq' , $args );
	
	register_taxonomy('faq-category', 
		array('faq'), 
		array(
		'hierarchical' => true, 
		'label' => 'FAQ Categories', 
		'singular_label' => 'FAQ Categories', 
		'rewrite' => true,
		'query_var' => true,
		'show_in_nav_menus'=> false
	));
}


/*******************************************************************
Manage Columns
********************************************************************/
add_filter('manage_edit-portfolio_columns', 'portfolio_edit_columns');
add_filter('manage_edit-team_columns', 'team_edit_columns');
add_filter('manage_edit-testimonial_columns', 'testimonial_edit_columns');
add_filter('manage_edit-pricing_columns', 'pricing_edit_columns');
add_filter('manage_edit-faq_columns', 'faq_edit_columns');
add_action('manage_posts_custom_column', 'posts_custom_columns', 10, 2);

function portfolio_edit_columns($columns)
{
	$newcolumns = array(
		'cb' => '<input type="checkbox" />',
		'title' => 'Title',
		'portfolio-category' => 'Categories'
	);
	
	$columns= array_merge($newcolumns, $columns);
	
	return $columns;
}

function team_edit_columns($columns)
{
	$newcolumns = array(
		'cb' => '<input type="checkbox" />',
		'title' => 'Title',
		'team-position' => 'Position',
		'team-category' => 'Categories'
	);
	
	$columns= array_merge($newcolumns, $columns);
	
	return $columns;
}

function testimonial_edit_columns($columns)
{
	$newcolumns = array(
		'cb' => '<input type="checkbox" />',
		'title' => 'Title',
		'testimonial-position' => 'Position'
	);
	
	$columns= array_merge($newcolumns, $columns);
	
	return $columns;
}

function pricing_edit_columns($columns)
{
	$newcolumns = array(
		'cb' => '<input type="checkbox" />',
		'title' => 'Title',
		'pricing-featured' => 'Featured',
		'pricing-cost' => 'Price',
		'pricing-category' => 'Categories'
	);
	
	$columns= array_merge($newcolumns, $columns);
	
	return $columns;
}

function faq_edit_columns($columns)
{
	$newcolumns = array(
		'cb' => '<input type="checkbox" />',
		'title' => 'Title',
		'faq-category' => 'Categories'
	);
	
	$columns= array_merge($newcolumns, $columns);
	
	return $columns;
}

function posts_custom_columns($column)
{
	global $post;
	
	switch ($column) {
		//
		case 'portfolio-category':
		echo get_the_term_list($post->ID, 'portfolio-category', '', ', ','');
		break;
		//
		case 'team-position':
		echo '<strong>'. get_post_meta($post->ID, '_team_position', TRUE) .'</strong>';
		break;
		case 'team-category':
		echo get_the_term_list($post->ID, 'team-category', '', ', ','');
		break;
		//
		case 'testimonial-position':
		echo '<strong>'. get_post_meta($post->ID, '_testimonial_position', TRUE) .'</strong>';
		break;
		//
		case 'pricing-featured':
		$featured = get_post_meta($post->ID, '_pricing_featured', TRUE);
		$featured = ( $featured == 1 ) ? 'Yes' : 'No';
		echo '<strong>'. $featured .'</strong>';
		break;
		case 'pricing-cost':
		echo '<strong>'. get_post_meta($post->ID, '_pricing_cost', TRUE) .'</strong>';
		break;
		case 'pricing-category':
		echo get_the_term_list($post->ID, 'pricing-category', '', ', ','');
		break;
		//
		case 'faq-category':
		echo get_the_term_list($post->ID, 'faq-category', '', ', ','');
		break;
	}
}


/*******************************************************************
Register Meta Box
********************************************************************/
add_filter( 'cmb_meta_boxes', 'pagebuilder_metaboxes' );
add_filter( 'cmb_meta_boxes', 'global_metaboxes' );
add_filter( 'cmb_meta_boxes', 'blog_metaboxes' );
add_filter( 'cmb_meta_boxes', 'page_metaboxes' );
add_filter( 'cmb_meta_boxes', 'portfolio_metaboxes' );
add_filter( 'cmb_meta_boxes', 'team_metaboxes' );
add_filter( 'cmb_meta_boxes', 'testimonial_metaboxes' );
add_filter( 'cmb_meta_boxes', 'client_metaboxes' );
add_filter( 'cmb_meta_boxes', 'pricing_metaboxes' );

function pagebuilder_metaboxes( array $meta_boxes ) {

	global $wpdb;
	
	$post_table = $wpdb->prefix.'posts';
	$pagebuilder = $wpdb->get_results("SELECT ID, post_title FROM {$post_table} WHERE post_type = 'template' ORDER BY post_title ASC LIMIT 100");
	$pb_opts = array();
	$pb_opts[0]['value'] = '';
	$pb_opts[0]['name'] = 'Select Template';
	$i = 1;
	foreach ( $pagebuilder as $k => $dt ) {
		$pb_opts[$i]['value'] = $dt->ID;
		$pb_opts[$i]['name'] = $dt->post_title;
		$i++;
	}
	
	// Start with an underscore to hide fields from custom fields list
	$prefix = '_pagebuilder_';
	
	$meta_boxes[] = array(
		'id'         => 'pagebuilder_metabox',
		'title'      => 'Page Builder Options',
		'pages'      => array( 'page' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		'fields'     => array(
			array(
				'name' => 'Enable Page Builder',
				'desc' => 'To build this page using page builder, please enable this option.<br />Page builder override/replace wordpress default editor.',
				'id'   => $prefix .'enable',
				'type' => 'checkbox',
			),
			array(
				'name' => 'Page Builder Template',
				'desc' => '<a href="'. admin_url( 'admin.php?page=aq-page-builder' ) .'">Create New</a>',
				'id'   => $prefix .'template',
				'type'    => 'select',
				'options' => $pb_opts,
			),
		),
	);
	
	return $meta_boxes;
}

function global_metaboxes( array $meta_boxes ) {

	global $wpdb;
	
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	
	$rev_opts = array();
	if ( is_plugin_active('revslider/revslider.php') ) {
		$revslider_table = $wpdb->prefix.'revslider_sliders';
		$revsliders = $wpdb->get_results("SELECT alias, title FROM {$revslider_table} ORDER BY title ASC LIMIT 100");
		foreach ( $revsliders as $k => $dt ) {
			$rev_opts[$k]['value'] = $dt->alias;
			$rev_opts[$k]['name'] = $dt->title;
		}
	}
	
	$layer_opts = array();
	if ( is_plugin_active('LayerSlider/layerslider.php') ) {
		$layerslider_table = $wpdb->prefix.'layerslider';
		$layersliders = $wpdb->get_results( "SELECT id, name FROM {$layerslider_table} WHERE flag_hidden = '0' AND flag_deleted = '0' ORDER BY name ASC LIMIT 100" );
		foreach ( $layersliders as $k => $dt ) {
			$layer_opts[$k]['value'] = $dt->id;
			$layer_opts[$k]['name'] = $dt->name;
		}
	}
	
	// Start with an underscore to hide fields from custom fields list
	$prefix = '_general_';
	
	$meta_boxes[] = array(
		'id'         => 'general_metabox',
		'title'      => 'General Options',
		'pages'      => array( 'page' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		'fields'     => array(
			array(
				'name'    => 'Top Slider',
				'desc'    => '',
				'id'      => $prefix .'slider',
				'type'    => 'select',
				'std'     => 'none',
				'options' => array(
					array( 'value' => '', 'name' => 'No Slider' ),
					array( 'value' => 'revslider', 'name' => 'Revolution Slider' ),
					array( 'value' => 'layerslider', 'name' => 'Layer Slider' ),
				),
			),
			array(
				'name' => 'Revolution Slider Alias',
				'desc' => '',
				'id'   => $prefix .'revslider',
				'type'    => 'select',
				'options' => $rev_opts,
			),
			array(
				'name' => 'Layer Slider Alias',
				'desc' => '',
				'id'   => $prefix .'layerslider',
				'type'    => 'select',
				'options' => $layer_opts,
			),
			array(
				'name' => 'Hide Page Title',
				'desc' => 'This functionality will hide page title and subtitle.',
				'id'   => $prefix .'hidetitle',
				'type' => 'checkbox',
			),
			array(
				'name'    => 'Title Position',
				'desc'    => '',
				'id'      => $prefix .'aligntitle',
				'type'    => 'select',
				'std'     => 'left',
				'options' => array(
					array( 'value' => 'left', 'name' => 'Left' ),
					array( 'value' => 'center', 'name' => 'Center' ),
				),
			),
			array(
				'name' => 'Sub Title',
				'desc' => '',
				'id'   => $prefix .'subtitle',
				'type' => 'text_large',
			),
			array(
				'name' => 'Hide Breadcrumb',
				'desc' => 'This functionality will hide breadcrumb.',
				'id'   => $prefix .'hidecrumb',
				'type' => 'checkbox',
			),
		),
	);
	
	$meta_boxes[] = array(
		'id'         => 'general_metabox',
		'title'      => 'General Options',
		'pages'      => array( 'post', 'portfolio' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		'fields'     => array(
			array(
				'name' => 'Sub Title',
				'desc' => '',
				'id'   => $prefix .'subtitle',
				'type' => 'text_large',
			),
		),
	);

	return $meta_boxes;
}

function blog_metaboxes( array $meta_boxes ) {

	// Start with an underscore to hide fields from custom fields list
	$prefix = '_blog_';
	
	$meta_boxes[] = array(
		'id'         => 'blog_format_metabox',
		'title'      => 'Post Formats',
		'pages'      => array( 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		'fields'     => array(
			array(
				'name' => 'Quote',
				'desc' => '',
				'id'   => $prefix .'quote',
				'type' => 'textarea_small',
			),
			array(
				'name' => 'Quote Author',
				'desc' => '',
				'id'   => $prefix .'quote_author',
				'type' => 'text_medium',
			),
			array(
				'name' => 'Youtube / Vimeo URL',
				'desc' => 'Example <span style="color:red">http://www.youtube.com/watch?v=1iIZeIy7TqM</span> OR <span style="color:red">http://vimeo.com/7449107</span>',
				'id'   => $prefix .'video',
				'type' => 'text_large',
			),
			array(
				'name' => 'Video Embed Code',
				'desc' => '',
				'id'   => $prefix .'video_embed',
				'type' => 'textarea_code',
			),
			array(
				'name' => 'Souncloud URL',
				'desc' => 'Example <span style="color:red">http://api.soundcloud.com/tracks/38987054</span>',
				'id'   => $prefix .'audio',
				'type' => 'text_large',
			),
		),
	);

	return $meta_boxes;
}

function page_metaboxes( array $meta_boxes ) {
	
	// Start with an underscore to hide fields from custom fields list
	$prefix = '_page_';

	$meta_boxes[] = array(
		'id'         => 'page_metabox',
		'title'      => 'Page Templates',
		'pages'      => array( 'page' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		'fields'     => array(		
			array(
				'name'    => 'Page Template',
				'desc'    => '',
				'id'      => $prefix .'template',
				'type'    => 'select',
				'options' => array(
					array( 'value' => 'default', 'name' => 'Page Default' ),
					array( 'value' => 'blog', 'name' => 'Blog' ),
					array( 'value' => 'portfolio', 'name' => 'Portfolio' ),
					array( 'value' => 'sitemap', 'name' => 'Sitemap' ),
				),
			),	
			array(
				'name'    => 'Page Layout',
				'desc'    => '',
				'id'      => $prefix .'default',
				'type'    => 'select',
				'std'     => 'fw',
				'options' => array(
					array( 'value' => 'fw', 'name' => 'Full Width' ),
					array( 'value' => 'lb', 'name' => 'Left Sidebar' ),
					array( 'value' => 'rb', 'name' => 'Right Sidebar' ),
				),
			),
			array(
				'name'    => 'Portfolio Layout',
				'desc'    => '',
				'id'      => $prefix .'portfolio',
				'type'    => 'select',
				'std'     => 'fw_4',
				'options' => array(					
					array( 'value' => 'fw_2', 'name' => '2 Columns' ),
					array( 'value' => 'fw_3', 'name' => '3 Columns' ),
					array( 'value' => 'fw_4', 'name' => '4 Columns' ),
				),
			),	
			array(
				'name'    => 'Page Sidebar',
				'desc'    => '',
				'id'      => $prefix .'sidebar',
				'type'    => 'select_sidebar',
				'std'     => ''
			),
		),
	);

	$meta_boxes[] = array(
		'id'         => 'page_blog_metabox',
		'title'      => 'Blog Options',
		'pages'      => array( 'page' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		'fields'     => array(
			array(
				'name'    => 'Category',
				'desc'    => 'If you do not select a category, it will show all.',
				'id'      => $prefix .'blog_cat',
				'type'    => 'taxonomy_multiselect',
				'taxonomy'=> 'category',
			),
			array(
				'name' => 'Display per Page',
				'desc' => '',
				'id'   => $prefix .'blog_num',
				'type' => 'text_small',
				'std'     => '10',
			),
		),
	);

	$meta_boxes[] = array(
		'id'         => 'page_portfolio_metabox',
		'title'      => 'Portfolio Options',
		'pages'      => array( 'page' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		'fields'     => array(
			array(
				'name'    => 'Category',
				'desc'    => 'If you do not select a category, it will show all.',
				'id'      => $prefix .'portfolio_cat',
				'type'    => 'taxonomy_multiselect',
				'taxonomy'=> 'portfolio-category',
			),
			array(
				'name' => 'Display per Page',
				'desc' => '',
				'id'   => $prefix .'portfolio_num',
				'type' => 'text_small',
				'std'     => '10',
			),
			array(
				'name'    => 'JQuery Filter',
				'desc'    => '',
				'id'      => $prefix .'portfolio_filter',
				'type'    => 'select',
				'std'     => '1',
				'options' => array(
					array( 'value' => '0', 'name' => 'Hide' ),
					array( 'value' => '1', 'name' => 'Show' ),
				),
			),
		),
	);

	return $meta_boxes;
}

function portfolio_metaboxes( array $meta_boxes ) {

	// Start with an underscore to hide fields from custom fields list
	$prefix = '_portfolio_';

	$meta_boxes[] = array(
		'id'         => 'portfolio_metabox',
		'title'      => 'Portfolio Attributes',
		'pages'      => array( 'portfolio' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		'fields'     => array(	
			array(
				'name'    => 'Layout',
				'desc'    => 'Layout in portfolio item',
				'id'      => $prefix .'layout',
				'type'    => 'select',
				'options' => array(
					array( 'value' => 'bottom', 'name' => 'Full Page' ),
					array( 'value' => 'left', 'name' => 'Left Side' ),
					array( 'value' => 'right', 'name' => 'Right Side' ),
				),
			),
			array(
				'name'    => 'Enable Lightbox',
				'desc'    => 'Lightbox hover in portfolio list.',
				'id'      => $prefix .'lightbox',
				'type'    => 'select',
				'options' => array(
					array( 'value' => '0', 'name' => 'No' ),
					array( 'value' => '1', 'name' => 'Yes' ),
				),
			),
			array(
				'name' => 'Date Added',
				'desc' => 'Date added/launch of portfolio.',
				'id'   => $prefix .'date',
				'type' => 'text_date_timestamp',
			),	
			array(
				'name' => 'Client Name',
				'desc' => 'Clients name of portfolio.',
				'id'   => $prefix .'client',
				'type' => 'text_medium',
			),
			array(
				'name' => 'Website URL',
				'desc' => 'A website to actual portfolio url.',
				'id'   => $prefix .'website',
				'type' => 'text_medium',
			),
			array(
				'name'    => 'Portfolio Type',
				'desc'    => '',
				'id'      => $prefix .'type',
				'type'    => 'select',
				'options' => array(
					array( 'value' => 'image', 'name' => 'Image' ),
					array( 'value' => 'video', 'name' => 'Video' ),
					array( 'value' => 'slider', 'name' => 'Slider' ),
				),
			),
			array(
				'name' => 'Image URL',
				'desc' => 'Upload an image or select from media or enter an URL.',
				'id'   => $prefix .'image',
				'type' => 'image',
			),
			array(
				'name' 	=> 'Thumbnail URL',
				'desc' 	=> 'Upload an image or select from media or enter an URL.',
				'id'   	=> $prefix .'video_thumb',
				'type' 	=> 'image',
			),
			array(
				'name' 	=> 'Video URL',
				'desc' 	=> 'This theme only supports video from Youtube and Vimeo.',
				'id'   	=> $prefix .'video',
				'type' 	=> 'text_large',
			),
			array(
				'name' => 'Slider',
				'desc' => 'Upload an image or select from media.',
				'id'   => $prefix .'slider',
				'type' => 'image_slider',
			),
		),
	);

	return $meta_boxes;
}

function team_metaboxes( array $meta_boxes ) {

	// Start with an underscore to hide fields from custom fields list
	$prefix = '_team_';

	$meta_boxes[] = array(
		'id'         => 'team_metabox',
		'title'      => 'Team Attributes',
		'pages'      => array( 'team' ), // Post type
		'context'    => 'normal',
		'priority'   => 'default',
		'show_names' => true, // Show field names on the left
		'fields'     => array(		
			array(
				'name' => 'Image URL',
				'desc' => 'Upload an image or select from media or enter an URL.',
				'id'   => $prefix .'image',
				'type' => 'image',
			),
			array(
				'name' => 'Position',
				'desc' => 'Enter position name in your company.',
				'id'   => $prefix .'position',
				'type' => 'text_medium',
			),	
			array(
				'name' => 'Email Address',
				'desc' => '',
				'id'   => $prefix .'email',
				'type' => 'text_medium',
			),
			array(
				'name' => 'Facebook URL',
				'desc' => '',
				'id'   => $prefix .'facebook',
				'type' => 'text_large',
			),
			array(
				'name' => 'Twitter URL',
				'desc' => '',
				'id'   => $prefix .'twitter',
				'type' => 'text_large',
			),
			array(
				'name' => 'Google+ URL',
				'desc' => '',
				'id'   => $prefix .'google',
				'type' => 'text_large',
			),
			array(
				'name' => 'LinkedIn URL',
				'desc' => '',
				'id'   => $prefix .'linkedin',
				'type' => 'text_large',
			),
			array(
				'name' => 'Dribbble URL',
				'desc' => '',
				'id'   => $prefix .'dribbble',
				'type' => 'text_large',
			),
		),
	);

	return $meta_boxes;
}

function testimonial_metaboxes( array $meta_boxes ) {

	// Start with an underscore to hide fields from custom fields list
	$prefix = '_testimonial_';

	$meta_boxes[] = array(
		'id'         => 'testimonial_metabox',
		'title'      => 'Testimonial Attributes',
		'pages'      => array( 'testimonial' ), // Post type
		'context'    => 'normal',
		'priority'   => 'default',
		'show_names' => true, // Show field names on the left
		'fields'     => array(		
			array(
				'name' => 'Image URL',
				'desc' => 'Upload an image or select from media or enter an URL.',
				'id'   => $prefix .'image',
				'type' => 'image',
			),
			array(
				'name' => 'Position',
				'desc' => 'Enter position name in this person.',
				'id'   => $prefix .'position',
				'type' => 'text_medium',
			),	
		),
	);

	return $meta_boxes;
}

function client_metaboxes( array $meta_boxes ) {

	// Start with an underscore to hide fields from custom fields list
	$prefix = '_client_';

	$meta_boxes[] = array(
		'id'         => 'client_metabox',
		'title'      => 'Client Attributes',
		'pages'      => array( 'client' ), // Post type
		'context'    => 'normal',
		'priority'   => 'default',
		'show_names' => true, // Show field names on the left
		'fields'     => array(	
			array(
				'name' => 'Image URL',
				'desc' => 'Upload an image or select from media or enter an URL.',
				'id'   => $prefix .'image',
				'type' => 'image',
			),
			array(
				'name' => 'Website URL',
				'desc' => 'Optional',
				'id'   => $prefix .'url',
				'type' => 'text_large',
			),	
		),
	);

	return $meta_boxes;
}

function pricing_metaboxes( array $meta_boxes ) {

	// Start with an underscore to hide fields from custom fields list
	$prefix = '_pricing_';

	$meta_boxes[] = array(
		'id'         => 'pricing_metabox',
		'title'      => 'Price Attributes',
		'pages'      => array( 'pricing' ), // Post type
		'context'    => 'normal',
		'priority'   => 'default',
		'show_names' => true, // Show field names on the left
		'fields'     => array(			
			array(
				'name'    => 'Featured',
				'desc'    => '',
				'id'      => $prefix .'featured',
				'type'    => 'select',
				'options' => array(
					array( 'value' => '0', 'name' => 'No' ),
					array( 'value' => '1', 'name' => 'Yes' ),
				),
			),	
			array(
				'name' => 'Price Cost',
				'desc' => 'Include currency',
				'id'   => $prefix .'cost',
				'type' => 'text_small',
			),	
			array(
				'name' => 'Price Note',
				'desc' => '',
				'id'   => $prefix .'note',
				'type' => 'text_medium',
			),	
			array(
				'name' => 'Button Label',
				'desc' => '',
				'id'   => $prefix .'btn_label',
				'type' => 'text_medium',
			),	
			array(
				'name' => 'Button Link',
				'desc' => '',
				'id'   => $prefix .'btn_link',
				'type' => 'text_medium',
			),	
		),
	);

	return $meta_boxes;
}

add_action( 'init', 'cmb_initialize_cmb_meta_boxes', 9999 );

function cmb_initialize_cmb_meta_boxes() {

	if ( ! class_exists( 'cmb_Meta_Box' ) )
		require_once ADMIN_PATH .'/metaboxes/init.php';

}
