<?php

/*******************************************************************
Twitter 
********************************************************************/
class slicetheme_twitter extends WP_Widget {

	function slicetheme_twitter()
	{
		$widget_ops = array('classname' => 'widget-twitter', 'description' => 'The most latest twitter messages on your site.' );
		
		$this->WP_Widget( 'st-twitter', THEMENAME.' - Latest Tweets', $widget_ops );
	}

	function widget( $args, $instance )
	{
		extract($args);
		
		$title = apply_filters('widget_title', empty($instance['title']) ? __('Latest Tweets', 'slicetheme') : $instance['title'], $instance, $this->id_base);
		$consumer_key = !empty($instance['consumer_key']) ? $instance['consumer_key'] : '';
		$consumer_secret = !empty($instance['consumer_secret']) ? $instance['consumer_secret'] : '';
		$access_token = !empty($instance['access_token']) ? $instance['access_token'] : '';
		$access_token_secret = !empty($instance['access_token_secret']) ? $instance['access_token_secret'] : '';
		$twitterID = !empty($instance['twitterID']) ? $instance['twitterID'] : '';
		$count = !empty($instance['count']) ? $instance['count'] : '';
		
		echo $before_widget;
		
		if ( !empty( $title ) ) { echo $before_title . $title . $after_title; }
		
		if ( $consumer_key && $consumer_secret && $access_token && $access_token_secret && $twitterID && $count )
		{ 
			require_once SLICETHEME_PATH .'/scripts/twitteroauth/twitteroauth.php';
			$transientName = 'st_twitter_'. $args['widget_id'];
			$cacheTime = 15;
			if ( false === ( $twit_data = get_transient($transientName) ) )
			{
				 require_once SLICETHEME_PATH .'/scripts/twitteroauth/twitteroauth.php';
				 $twit_connect = new TwitterOAuth(
												$consumer_key,		// Consumer Key
												$consumer_secret,   // Consumer secret
												$access_token,      // Access token
												$access_token_secret// Access token secret
												);
				 $twit_data = $twit_connect->get('statuses/user_timeline', array(
																				'screen_name'     => $twitterID,
																				'count'           => $count,
																				'exclude_replies' => false
																				)
																			);
				 if ( $twit_connect->http_code != 200 )
				 {
					  $twit_data = get_transient($transientName);
				 }
				 set_transient($transientName, $twit_data, 60 * $cacheTime);
			}
			
			$twitter = get_transient($transientName);
			if ( $twitter && is_array($twitter) )
			{
				?>
				<ul class="unstyled" id="twitter_<?php echo $args['widget_id']; ?>">
					<?php
					foreach ( $twitter as $tweet )
					{
						$status = $tweet->text;
						$status = preg_replace('/http:\/\/([a-z0-9_\.\-\+\&\!\#\~\/\,]+)/i', '<a href="http://$1" target="_blank">http://$1</a>', $status);
						$status = preg_replace('/@([a-z0-9_]+)/i', '<a href="http://twitter.com/$1" target="_blank">@$1</a>', $status);
						
						$timer = strtotime($tweet->created_at);
						$timer = $this->relative_time($timer);
						?>						
						<li><span><?php echo $status; ?></span> <a style="font-size:85%" href="http://twitter.com/<?php echo $tweet->user->screen_name; ?>/statuses/<?php echo $tweet->id_str; ?>"><?php echo $timer; ?></a></li>
						<?php
					}
					?>
				</ul>
				<?php
			}
		}
		
		echo $after_widget;
	}
	
	function relative_time($time)
	{
		$gap = time() - $time;
	
		if ($gap < 5) {
			return 'less than 5 seconds ago';
		} else if ($gap < 10) {
			return 'less than 10 seconds ago';
		} else if ($gap < 20) {
			return 'less than 20 seconds ago';
		} else if ($gap < 40) {
			return 'half a minute ago';
		} else if ($gap < 60) {
			return 'less than a minute ago';
		}
	
		$gap = round($gap / 60);
		if ($gap < 60)  { 
			return $gap.' minute'.($gap > 1 ? 's' : '').' ago';
		}
	
		$gap = round($gap / 60);
		if ($gap < 24)  { 
			return 'about '.$gap.' hour'.($gap > 1 ? 's' : '').' ago';
		}
	
		return date('h:i A F d, Y', $time);
	}

	function update( $new_instance, $old_instance )
	{
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['consumer_key'] = strip_tags($new_instance['consumer_key']);
		$instance['consumer_secret'] = strip_tags($new_instance['consumer_secret']);
		$instance['access_token'] = strip_tags($new_instance['access_token']);
		$instance['access_token_secret'] = strip_tags($new_instance['access_token_secret']);
		$instance['twitterID'] = strip_tags($new_instance['twitterID']);
		$instance['count'] = strip_tags($new_instance['count']);
		return $instance;
	}

	function form( $instance )
	{		
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'twitterID' => '', 'count' => 5 ) );
		$title = strip_tags($instance['title']);
		$consumer_key = strip_tags($instance['consumer_key']);
		$consumer_secret = strip_tags($instance['consumer_secret']);
		$access_token = strip_tags($instance['access_token']);
		$access_token_secret = strip_tags($instance['access_token_secret']);
		$twitterID = strip_tags($instance['twitterID']);
		$count = strip_tags($instance['count']);
		
		?>
		<p><a href="http://dev.twitter.com/apps">Find or Create your Twitter App</a></p>
		
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>">Title:</label>
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('consumer_key'); ?>">Consumer Key:</label>
			<input class="widefat" id="<?php echo $this->get_field_id('consumer_key'); ?>" name="<?php echo $this->get_field_name('consumer_key'); ?>" type="text" value="<?php echo esc_attr($consumer_key); ?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('consumer_secret'); ?>">Consumer Secret:</label>
			<input class="widefat" id="<?php echo $this->get_field_id('consumer_secret'); ?>" name="<?php echo $this->get_field_name('consumer_secret'); ?>" type="text" value="<?php echo esc_attr($consumer_secret); ?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('access_token'); ?>">Access Token:</label>
			<input class="widefat" id="<?php echo $this->get_field_id('access_token'); ?>" name="<?php echo $this->get_field_name('access_token'); ?>" type="text" value="<?php echo esc_attr($access_token); ?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('access_token_secret'); ?>">Access Token Secret:</label>
			<input class="widefat" id="<?php echo $this->get_field_id('access_token_secret'); ?>" name="<?php echo $this->get_field_name('access_token_secret'); ?>" type="text" value="<?php echo esc_attr($access_token_secret); ?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('twitterID'); ?>">Twitter ID:</label>
			<input class="widefat" id="<?php echo $this->get_field_id('twitterID'); ?>" name="<?php echo $this->get_field_name('twitterID'); ?>" type="text" value="<?php echo esc_attr($twitterID); ?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('count'); ?>">Number to display:</label>
			<select id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>">
				<?php
				for ( $i = 1; $i <= 10; $i++ )
				{					
					$selected = ($count == $i) ? ' selected' : '';
				
					echo '<option value="'.$i.'"'. $selected .'>'.$i.'</option>';
				}
				?>
			</select>
		</p>
		<?php
	}
}


/*******************************************************************
Flick 
********************************************************************/
class slicetheme_flickr extends WP_Widget {

	function slicetheme_flickr()
	{
		$widget_ops = array('classname' => 'widget-flickr', 'description' => 'The most latest flickr photo on your site.' );
		
		$this->WP_Widget( 'st-flickr', THEMENAME.' - Latest Flickr Photos', $widget_ops );
	}

	function widget( $args, $instance )
	{
		extract($args);
		
		$title = apply_filters('widget_title', empty($instance['title']) ? __('Latest Flickr Photos', 'slicetheme') : $instance['title'], $instance, $this->id_base);
		$flickrID = !empty($instance['flickrID']) ? $instance['flickrID'] : '';
		$count = !empty($instance['count']) ? $instance['count'] : '';
		$display = !empty($instance['display']) ? $instance['display'] : '';
		
		echo $before_widget;
		
		if ( !empty( $title ) ) { echo $before_title . $title . $after_title; }
		
		?>
		<script type="text/javascript" src="http://www.flickr.com/badge_code_v2.gne?count=<?php echo $count; ?>&amp;display=<?php echo $display; ?>&amp;size=s&amp;layout=x&amp;source=user&amp;user=<?php echo $flickrID; ?>"></script>
		<?php
		
		echo $after_widget;
	}

	function update( $new_instance, $old_instance )
	{
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['flickrID'] = strip_tags($new_instance['flickrID']);
		$instance['count'] = strip_tags($new_instance['count']);
		$instance['display'] = strip_tags($new_instance['display']);
		return $instance;
	}

	function form( $instance )
	{		
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'flickrID' => '', 'display' => 'latest', 'count' => 9 ) );
		$title = strip_tags($instance['title']);
		$flickrID = strip_tags($instance['flickrID']);
		$count = strip_tags($instance['count']);
		$display = strip_tags($instance['display']);
		
		$display_opt = array('latest', 'random');
		
		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>">Title:</label>
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('flickrID'); ?>">Flickr ID:</label>
			<input class="widefat" id="<?php echo $this->get_field_id('flickrID'); ?>" name="<?php echo $this->get_field_name('flickrID'); ?>" type="text" value="<?php echo esc_attr($flickrID); ?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('display'); ?>">What pictures to display:</label>
			<select class="widefat" id="<?php echo $this->get_field_id('display'); ?>" name="<?php echo $this->get_field_name('display'); ?>">
				<?php
				foreach ( $display_opt as $opt )
				{					
					$selected = ($display == $opt) ? ' selected' : '';
				
					echo '<option value="'.$opt.'"'. $selected .'>'.ucfirst($opt).'</option>';
				}
				?>
			</select>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('count'); ?>">Number to display:</label>
			<select id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>">
				<?php
				for ( $i = 1; $i <= 10; $i++ )
				{					
					$selected = ($count == $i) ? ' selected' : '';
				
					echo '<option value="'.$i.'"'. $selected .'>'.$i.'</option>';
				}
				?>
			</select>
		</p>
		<?php
	}
}


/*******************************************************************
Contact Form 
********************************************************************/
class slicetheme_contact extends WP_Widget {

	function slicetheme_contact()
	{
		$widget_ops = array('classname' => 'widget-contact', 'description' => 'Display your contact form.' );
		
		$this->WP_Widget( 'st-contact', THEMENAME.' - Contact Form', $widget_ops );
	}

	function widget( $args, $instance )
	{
		extract($args);
		
		$title = apply_filters('widget_title', empty($instance['title']) ? __('Quick Contact', 'slicetheme') : $instance['title'], $instance, $this->id_base);
		
		echo $before_widget;
		
		if ( !empty( $title ) ) { echo $before_title . $title . $after_title; }
		
		$rand = uniqid();
		
		?>
		<script type="text/javascript">
		jQuery(function($) {
			$('#contact_wgt_<?php echo $rand; ?>').submit(function () {
				$('#result_contact_wgt_<?php echo $rand; ?>').hide();
				$.ajax({
					type: 'POST',
					url: $(this).attr('action'),
					data: $(this).serialize(),
					success: function (data) {
						$('#result_contact_wgt_<?php echo $rand; ?>').html(data).fadeIn('fast');
					}
				});
				return false;
			});
		});
		</script>
		
		<div id="result_contact_wgt_<?php echo $rand; ?>"></div>
		
		<form id="contact_wgt_<?php echo $rand; ?>" method="post" action="<?php echo SLICETHEME_URL .'/scripts/contact.php'; ?>">
			<label for="contact_name"><?php _e('Name', 'slicetheme'); ?></label>
			<input type="text" class="span12" name="contact_name" id="contact_name" />
			<label for="contact_email"><?php _e('Email', 'slicetheme'); ?></label>
			<input type="text" class="span12" name="contact_email" id="contact_email" />			
			<label for="contact_subject"><?php _e('Subject', 'slicetheme'); ?></label>
			<input type="text" class="span12" name="contact_subject" id="contact_subject" />			
			<label for="contact_message"><?php _e('Message', 'slicetheme'); ?></label>
			<textarea class="span12" name="contact_message" id="contact_message" rows="4"></textarea>
			<input type="submit" class="btn" name="submit" value="<?php _e('Send', 'slicetheme'); ?>" id="contact-wgt-submit" />
		</form>
		<?php
		
		echo $after_widget;
	}

	function update( $new_instance, $old_instance )
	{
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		return $instance;
	}

	function form( $instance )
	{		
		$instance = wp_parse_args( (array) $instance, array( 'title' => '' ) );
		$title = strip_tags($instance['title']);
		
		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>">Title:</label>
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>
		<?php
	}
}


/*******************************************************************
Latest Posts
********************************************************************/
class slicetheme_blog extends WP_Widget {

	function slicetheme_blog()
	{
		$widget_ops = array('classname' => 'widget-blog', 'description' => 'The most latest posts on your site.' );
		
		$this->WP_Widget( 'st-blog', THEMENAME.' - Latest Posts', $widget_ops );
	}

	function widget( $args, $instance )
	{
		extract($args);
		
		$title = apply_filters('widget_title', empty($instance['title']) ? __('Latest Posts', 'slicetheme') : $instance['title'], $instance, $this->id_base);
		$cat = !empty($instance['cat']) ? $instance['cat'] : '';
		$count = !empty($instance['count']) ? $instance['count'] : '';
		
		echo $before_widget;
		
		if ( !empty( $title ) ) { echo $before_title . $title . $after_title; }
		
		if ( !empty($cat) ) {
			$loop = new WP_Query('cat='.$cat.'&posts_per_page='.$count);
		}
		else {
			$loop = new WP_Query('&posts_per_page='.$count);
		}
		
		if ($loop->have_posts()) :		
		?>
		<ul class="media-list">
			<?php
			while ($loop->have_posts()) : $loop->the_post();
				?>
				<li class="media">
					<?php
					if ( current_theme_supports('post-thumbnails') && has_post_thumbnail() ) {
						$thumbURL = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), '');
						$thumbURL = $thumbURL[0];
						?>
						<div class="pull-left">
							<a href="<?php the_permalink() ?>" title="<?php the_title(); ?>">
							<?php slicetheme_resizer($thumbURL, 55, 50); ?>
							</a>
						</div>
						<?php
					}
					?>
					<div class="media-body">
						<a href="<?php the_permalink() ?>" title="<?php the_title(); ?>"><?php the_title(); ?></a>
						<span class="time"><?php the_time('F j, Y'); ?></span>
					</div>
				</li>
				<?php
			endwhile;
			?>
		</ul>
		<?php		
		wp_reset_postdata();
		endif;
		
		echo $after_widget;
	}

	function update( $new_instance, $old_instance )
	{
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['cat'] = strip_tags($new_instance['cat']);
		$instance['count'] = strip_tags($new_instance['count']);
		return $instance;
	}

	function form( $instance )
	{		
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'cat' => '', 'count' => 5 ) );
		$title = strip_tags($instance['title']);
		$cat = strip_tags($instance['cat']);
		$count = strip_tags($instance['count']);
		
		$categories_list = get_categories('hide_empty=0');		
		$categories = array();
		$categories[''] = 'All';
		foreach ($categories_list as $category) {
			$categories[$category->cat_ID] = $category->cat_name;
		}
		
		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>">Title:</label>
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('cat'); ?>">Choose the categories:</label>
			<select class="widefat" id="<?php echo $this->get_field_id('cat'); ?>" name="<?php echo $this->get_field_name('cat'); ?>">
				<?php
				foreach ( $categories as $id => $name )
				{					
					$selected = ($cat == $id) ? ' selected' : '';
				
					echo '<option value="'.$id.'"'. $selected .'>'.$name.'</option>';
				}
				?>
			</select>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('count'); ?>">Number to display:</label>
			<select id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>">
				<?php
				for ( $i = 1; $i <= 10; $i++ )
				{					
					$selected = ($count == $i) ? ' selected' : '';
				
					echo '<option value="'.$i.'"'. $selected .'>'.$i.'</option>';
				}
				?>
			</select>
		</p>
		<?php
	}
}


function slicetheme_register_widgets() {
	register_widget( 'slicetheme_twitter' );
	register_widget( 'slicetheme_flickr' );
	register_widget( 'slicetheme_contact' );
	register_widget( 'slicetheme_blog' );
}

add_action( 'widgets_init', 'slicetheme_register_widgets' );